@@ -91,7 +91,7 @@ static void feh_wm_set_bg_scaled(Pixmap pmap, Imlib_Image im, int use_filelist,
 		feh_wm_load_next(&im);
 
 	gib_imlib_render_image_on_drawable_at_size(pmap, im, x, y, w, h,
-			1, 0, !opt.force_aliasing);
+			1, 1, !opt.force_aliasing);
 
 	if (use_filelist)
 		gib_imlib_free_image_and_decache(im);
@@ -132,7 +132,7 @@ static void feh_wm_set_bg_centered(Pixmap pmap, Imlib_Image im, int use_filelist
 		y + ((offset_y > 0) ? offset_y : 0),
 		w,
 		h,
-		1, 0, 0);
+		1, 1, 0);
 
 	if (use_filelist)
 		gib_imlib_free_image_and_decache(im);
@@ -160,11 +160,36 @@ static void feh_wm_set_bg_filled(Pixmap pmap, Imlib_Image im, int use_filelist,
 	render_x = (  cut_x ? ((img_w - render_w) >> 1) : 0);
 	render_y = ( !cut_x ? ((img_h - render_h) >> 1) : 0);
 
+	if ((opt.geom_flags & XValue) && cut_x) {
+		if (opt.geom_flags & XNegative) {
+			render_x = img_w - render_w + opt.geom_x;
+		} else {
+			render_x = opt.geom_x;
+		}
+		if (render_x < 0) {
+			render_x = 0;
+		} else if (render_x + render_w > img_w) {
+			render_x = img_w - render_w;
+		}
+	}
+	else if ((opt.geom_flags & YValue) && !cut_x) {
+		if (opt.geom_flags & YNegative) {
+			render_y = img_h - render_h + opt.geom_y;
+		} else {
+			render_y = opt.geom_y;
+		}
+		if (render_y < 0) {
+			render_y = 0;
+		} else if (render_y + render_h > img_h) {
+			render_y = img_h - render_h;
+		}
+	}
+
 	gib_imlib_render_image_part_on_drawable_at_size(pmap, im,
 		render_x, render_y,
 		render_w, render_h,
 		x, y, w, h,
-		1, 0, !opt.force_aliasing);
+		1, 1, !opt.force_aliasing);
 
 	if (use_filelist)
 		gib_imlib_free_image_and_decache(im);
@@ -212,7 +237,7 @@ static void feh_wm_set_bg_maxed(Pixmap pmap, Imlib_Image im, int use_filelist,
 	gib_imlib_render_image_on_drawable_at_size(pmap, im,
 		render_x, render_y,
 		render_w, render_h,
-		1, 0, !opt.force_aliasing);
+		1, 1, !opt.force_aliasing);
 
 	if (use_filelist)
 		gib_imlib_free_image_and_decache(im);
@@ -307,15 +332,19 @@ void feh_wm_set_bg(char *fil, Imlib_Image im, int centered, int scaled,
 
 		D(("Falling back to XSetRootWindowPixmap\n"));
 
+		XColor color;
+		Colormap cmap = DefaultColormap(disp, DefaultScreen(disp));
+		if (opt.image_bg)
+			XAllocNamedColor(disp, cmap, (char*) opt.image_bg, &color, &color);
+		else
+			XAllocNamedColor(disp, cmap, "black", &color, &color);
+
 		if (scaled) {
 			pmap_d1 = XCreatePixmap(disp, root, scr->width, scr->height, depth);
 
 #ifdef HAVE_LIBXINERAMA
 			if (opt.xinerama_index >= 0) {
-				if (opt.image_bg == IMAGE_BG_WHITE)
-					gcval.foreground = WhitePixel(disp, DefaultScreen(disp));
-				else
-					gcval.foreground = BlackPixel(disp, DefaultScreen(disp));
+				gcval.foreground = color.pixel;
 				gc = XCreateGC(disp, root, GCForeground, &gcval);
 				XFillRectangle(disp, pmap_d1, gc, 0, 0, scr->width, scr->height);
 				XFreeGC(disp, gc);
@@ -339,10 +368,7 @@ void feh_wm_set_bg(char *fil, Imlib_Image im, int centered, int scaled,
 			D(("centering\n"));
 
 			pmap_d1 = XCreatePixmap(disp, root, scr->width, scr->height, depth);
-			if (opt.image_bg == IMAGE_BG_WHITE)
-				gcval.foreground = WhitePixel(disp, DefaultScreen(disp));
-			else
-				gcval.foreground = BlackPixel(disp, DefaultScreen(disp));
+			gcval.foreground = color.pixel;
 			gc = XCreateGC(disp, root, GCForeground, &gcval);
 			XFillRectangle(disp, pmap_d1, gc, 0, 0, scr->width, scr->height);
 
@@ -369,10 +395,7 @@ void feh_wm_set_bg(char *fil, Imlib_Image im, int centered, int scaled,
 
 #ifdef HAVE_LIBXINERAMA
 			if (opt.xinerama_index >= 0) {
-				if (opt.image_bg == IMAGE_BG_WHITE)
-					gcval.foreground = WhitePixel(disp, DefaultScreen(disp));
-				else
-					gcval.foreground = BlackPixel(disp, DefaultScreen(disp));
+				gcval.foreground = color.pixel;
 				gc = XCreateGC(disp, root, GCForeground, &gcval);
 				XFillRectangle(disp, pmap_d1, gc, 0, 0, scr->width, scr->height);
 				XFreeGC(disp, gc);
@@ -395,10 +418,7 @@ void feh_wm_set_bg(char *fil, Imlib_Image im, int centered, int scaled,
 		} else if (filled == 2) {
 
 			pmap_d1 = XCreatePixmap(disp, root, scr->width, scr->height, depth);
-			if (opt.image_bg == IMAGE_BG_WHITE)
-				gcval.foreground = WhitePixel(disp, DefaultScreen(disp));
-			else
-				gcval.foreground = BlackPixel(disp, DefaultScreen(disp));
+			gcval.foreground = color.pixel;
 			gc = XCreateGC(disp, root, GCForeground, &gcval);
 			XFillRectangle(disp, pmap_d1, gc, 0, 0, scr->width, scr->height);
 
@@ -425,7 +445,7 @@ void feh_wm_set_bg(char *fil, Imlib_Image im, int centered, int scaled,
 			w = gib_imlib_image_get_width(im);
 			h = gib_imlib_image_get_height(im);
 			pmap_d1 = XCreatePixmap(disp, root, w, h, depth);
-			gib_imlib_render_image_on_drawable(pmap_d1, im, 0, 0, 1, 0, 0);
+			gib_imlib_render_image_on_drawable(pmap_d1, im, 0, 0, 1, 1, 0);
 		}
 
 		if (!opt.no_fehbg) {
@@ -474,7 +494,7 @@ void feh_wm_set_bg(char *fil, Imlib_Image im, int centered, int scaled,
 				free(path);
 			}
 		}
-		
+
 		/* create new display, copy pixmap to new display */
 		disp2 = XOpenDisplay(NULL);
 		if (!disp2)
